@@ -9,20 +9,16 @@ import com.example.types.Headers;
 public class NeedsAuthTestCase extends TestServiceTestCase {
 
     @Test
-    public void test() {
+    public void test() throws Exception {
         TestBindingStub stub = (TestBindingStub)port;
-        stub.setHeader("http://example.com/", "headers",
+        stub.setHeader(
+            "http://example.com/", "headers",
             (new Headers("user", "pass")));
-        try {
-            Assert.assertTrue(
-                port.say_hello().equals("hello user"));
-        } catch (java.rmi.RemoteException e) {
-            System.out.println("Exception: " + e.toString());
-        }
+        Assert.assertEquals("hello user", port.say_hello());
     }
 
     @Test
-    public void test_exception() {
+    public void test_exception() throws Exception {
         TestBindingStub stub = (TestBindingStub)port;
         stub.setHeader("http://example.com/", "headers",
             (new Headers("fake", "pass")));
@@ -32,8 +28,6 @@ public class NeedsAuthTestCase extends TestServiceTestCase {
             Assert.assertTrue(
                 e.toString().equals("Access denied for user fake"));
             return;
-        } catch (java.rmi.RemoteException e) {
-            System.out.println("Exception: " + e.toString());
         }
         Assert.assertTrue("Exception hasn't been thrown", false);
     }
