@@ -13,5 +13,5 @@ class NextMonthTestCase(BaseTestCaseMixin, unittest.TestCase):
 
     def test_dt(self):
         self.assertEqual(
-            self.service.next_month_dt(datetime(2011, 8, 20, 0, 4, 59)),
-            datetime(2011, 9, 20, 0, 4, 59))
+            self.service.next_month_dt(datetime(2011, 8, 20, 0, 4, 59, 123)),
+            datetime(2011, 9, 20, 0, 4, 59, 123))
